# Chapter 14: High-Performance Factor Mining and Expression Engine

This chapter is currently maintained in Chinese first.

- Chinese chapter: [第 14 章：高性能因子挖掘与表达式引擎](../../zh/textbook/14_factor.md)
- Textbook home: [Chinese textbook index](../../zh/textbook/index.md)
- Practice links:
  - Primary example: [examples/textbook/ch14_factor.py](https://github.com/akfamily/akquant/blob/main/examples/textbook/ch14_factor.py)
  - Extended example: [examples/16_adj_returns_signal.py](https://github.com/akfamily/akquant/blob/main/examples/16_adj_returns_signal.py)
  - Guide: [Factor Guide](../guide/factor.md)
